@@ -1,9 +1,6 @@
 use std::{io, io::BufRead};
 
-use crate::{
-    immutable::{Band, Text},
-    PacketLine, StreamingPeekableIter, U16_HEX_BYTES,
-};
+use crate::{BandRef, PacketLineRef, StreamingPeekableIter, TextRef, U16_HEX_BYTES};
 
 /// An implementor of [`BufRead`][io::BufRead] yielding packet lines on each call to [`read_line()`][io::BufRead::read_line()].
 /// It's also possible to hide the underlying packet lines using the [`Read`][io::Read] implementation which is useful
@@ -71,12 +68,12 @@ where
     }
 
     /// Forwards to the parent [StreamingPeekableIter::reset_with()]
-    pub fn reset_with(&mut self, delimiters: &'static [PacketLine<'static>]) {
+    pub fn reset_with(&mut self, delimiters: &'static [PacketLineRef<'static>]) {
         self.parent.reset_with(delimiters)
     }
 
     /// Forwards to the parent [StreamingPeekableIter::stopped_at()]
-    pub fn stopped_at(&self) -> Option<PacketLine<'static>> {
+    pub fn stopped_at(&self) -> Option<PacketLineRef<'static>> {
         self.parent.stopped_at
     }
 
@@ -89,7 +86,7 @@ where
     /// next on a call to [`read_line()`][io::BufRead::read_line()].
     pub fn peek_data_line(&mut self) -> Option<io::Result<Result<&[u8], crate::decode::Error>>> {
         match self.parent.peek_line() {
-            Some(Ok(Ok(crate::PacketLine::Data(line)))) => Some(Ok(Ok(line))),
+            Some(Ok(Ok(crate::PacketLineRef::Data(line)))) => Some(Ok(Ok(line))),
             Some(Ok(Err(err))) => Some(Ok(Err(err))),
             Some(Err(err)) => Some(Err(err)),
             _ => None,
@@ -116,13 +113,13 @@ where
                             .map_err(|err| io::Error::new(io::ErrorKind::Other, err))?;
                         const ENCODED_BAND: usize = 1;
                         match band {
-                            Band::Data(d) => break (U16_HEX_BYTES + ENCODED_BAND, d.len()),
-                            Band::Progress(d) => {
-                                let text = Text::from(d).0;
+                            BandRef::Data(d) => break (U16_HEX_BYTES + ENCODED_BAND, d.len()),
+                            BandRef::Progress(d) => {
+                                let text = TextRef::from(d).0;
                                 handle_progress(false, text);
                             }
-                            Band::Error(d) => {
-                                let text = Text::from(d).0;
+                            BandRef::Error(d) => {
+                                let text = TextRef::from(d).0;
                                 handle_progress(true, text);
                             }
                         };
